@@ -39,7 +39,7 @@ class Translator:
         """
         if original == '':
             return ''
-        assert original, 'Cannot translate: {}'.format(original)
+        assert original, f'Cannot translate: {original}'
         # Because the original string is what the text extractors put into the
         # catalog, we must first look up the original unadulterated string in
         # the catalog.  Use the global translation context for this.
